@@ -1,5 +1,5 @@
-# Copyright (c) 2003-2006 Sylvain Thenault (thenault@gmail.com).
-# Copyright (c) 2003-2006 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2007 Sylvain Thenault (thenault@gmail.com).
+# Copyright (c) 2003-2007 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -54,8 +54,8 @@ from pylint.utils import UnknownMessage, MessagesHandlerMixIn, \
 from pylint.interfaces import ILinter, IRawChecker, IASTNGChecker
 from pylint.checkers import BaseRawChecker, EmptyReport, \
      table_lines_from_stats
-from pylint.reporters.text import TextReporter, TextReporter2, \
-     ColorizedTextReporter
+from pylint.reporters.text import TextReporter, ParseableTextReporter, \
+     VSTextReporter, ColorizedTextReporter
 from pylint.reporters.html import HTMLReporter
 from pylint import config
 
@@ -64,7 +64,8 @@ from pylint.__pkginfo__ import version
 
 OPTION_RGX = re.compile('\s*#*\s*pylint:(.*)')
 REPORTER_OPT_MAP = {'text': TextReporter,
-                    'parseable': TextReporter2,
+                    'parseable': ParseableTextReporter,
+                    'msvs': VSTextReporter,
                     'colorized': ColorizedTextReporter,
                     'html': HTMLReporter,}
 
@@ -81,6 +82,9 @@ MSGS = {
     'F0003': ('ignored builtin module %s',
               'Used to indicate that the user asked to analyze a builtin module\
               which has been skipped.'),
+    'F0004': ('unexpected infered value %s',
+              'Used to indicate that some value of an unexpected type has been \
+              infered.'),
     
     'I0001': ('Unable to run raw checkers on built-in module %s',
               'Used to inform that a built-in module has not been checked \
@@ -96,6 +100,9 @@ be used inside modules.'),
     'I0012': ('Locally enabling %s',
               'Used when an inline option enable a message or a messages \
               category.'),
+    'I0013': ('Ignoring entire file',
+              'Used to inform that the file will not be checked'),
+
     
     'E0001': ('%s',
               'Used when a syntax error is raised for a module.'),
@@ -134,14 +141,14 @@ should be a base name, not a path. You may set this option multiple times.'}),
                 {'type' : 'csv', 'metavar': '<checker ids>',
                  'group': 'Messages control',
                  'help' : 'Enable only checker(s) with the given id(s).\
-                 This option conflict with the disable-checker option'}),
+                 This option conflicts with the disable-checker option'}),
             
                ('disable-checker',
                 {'type' : 'csv', 'metavar': '<checker ids>',
                  'group': 'Messages control',
                  'help' : 'Enable all checker(s) except those with the \
                  given id(s).\
-                 This option conflict with the disable-checker option'}),
+                 This option conflicts with the enable-checker option'}),
                
                ('persistent',
                 {'default': True, 'type' : 'yn', 'metavar' : '<y_or_n>',
@@ -158,11 +165,11 @@ python modules names) to load, usually to register additional checkers.'}),
                
                ('output-format',
                 {'default': 'text', 'type': 'choice', 'metavar' : '<format>',
-                 'choices': ('text', 'parseable', 'colorized', 'html'),
+                 'choices': ('text', 'parseable', 'msvs', 'colorized', 'html'),
                  'short': 'f',
                  'group': 'Reports',
                  'help' : 'set the output format. Available formats are text,\
-                 parseable, colorized and html'}),
+                 parseable, colorized, msvs (visual studio) and html'}),
 
                ('include-ids',
                 {'type' : 'yn', 'metavar' : '<y_or_n>', 'default' : 0,
@@ -244,6 +251,7 @@ This is used by the global evaluation report (R0004).'}),
         self.reporter = None
         self.manager = ASTNGManager()
         self._checkers = {}
+        self._ignore_file = False        
         # visit variables
         self.base_name = None
         self.base_file = None
@@ -331,7 +339,7 @@ This is used by the global evaluation report (R0004).'}),
         checker is an object implementing IRawChecker or / and IASTNGChecker
         """
         assert checker.priority <= 0, 'checker priority can\'t be >= 0'
-        self._checkers[checker] = 1
+        self._checkers[checker.name] = checker
         if hasattr(checker, 'reports'):
             for r_id, r_title, r_cb in checker.reports:
                 self.register_report(r_id, r_title, r_cb, checker)
@@ -342,13 +350,14 @@ This is used by the global evaluation report (R0004).'}),
                 
     def enable_checkers(self, listed, enabled):
         """only enable/disable checkers from the given list"""
-        idmap = {}
-        for checker in self._checkers.keys():
-            checker.enable(not enabled)
-            idmap[checker.name] = checker
+        if enabled: # if we are activating a checker; deactivate them all first
+            for checker in self._checkers.values():
+                if not checker.may_be_disabled:
+                    continue
+                checker.enable(not enabled)
         for checkerid in listed:
             try:
-                checker = idmap[checkerid]
+                checker = self._checkers[checkerid]
             except KeyError:
                 raise Exception('no checker named %s' % checkerid)
             checker.enable(enabled)
@@ -358,16 +367,18 @@ This is used by the global evaluation report (R0004).'}),
         'miscellaneous' checker which can be safely deactivated in debug
         mode
         """
-        for checker in self._checkers.keys():
+        for checker in self._checkers.values():
             if checker.name == 'miscellaneous':
                 checker.enable(False)
                 continue
-            for msgid in getattr(checker, 'msgs', {}).keys():
-                if msgid[0] == 'E':
-                    checker.enable(True)
-                    break
-            else:
-                checker.enable(False)
+            # if checker is already explicitly disabled (e.g. rpython), don't enable it
+            if checker.enabled:
+                for msgid in getattr(checker, 'msgs', {}).keys():
+                    if msgid[0] == 'E':
+                        checker.enable(True)
+                        break
+                else:
+                    checker.enable(False)
                 
     # block level option handling #############################################
     #
@@ -388,6 +399,10 @@ This is used by the global evaluation report (R0004).'}),
             match = OPTION_RGX.search(line)
             if match is None:
                 continue
+            if match.group(1).strip() == "disable-all":
+                self.add_message('I0013', line=start[0])
+                self._ignore_file = True
+                return
             try:
                 opt, value = match.group(1).split('=', 1)
             except ValueError:
@@ -439,7 +454,7 @@ This is used by the global evaluation report (R0004).'}),
         self.reporter.include_ids = self.config.include_ids
         if not isinstance(files_or_modules, (list, tuple)):
             files_or_modules = (files_or_modules,)
-        checkers = sort_checkers(self._checkers.keys())
+        checkers = sort_checkers(self._checkers.values())
         rev_checkers = checkers[:]
         rev_checkers.reverse()
         # notify global begin
@@ -478,7 +493,10 @@ This is used by the global evaluation report (R0004).'}),
             if self.config.files_output:
                 reportfile = 'pylint_%s.%s' % (modname, self.reporter.extension)
                 self.reporter.set_output(open(reportfile, 'w'))
-            self.check_file(filepath, modname, checkers)
+            try:
+                self.check_file(filepath, modname, checkers)
+            except SyntaxError, ex:
+                self.add_message('E0001', line=ex.lineno, args=ex.msg)
         # notify global end
         self.set_current_module('')
         for checker in rev_checkers:
@@ -492,6 +510,7 @@ This is used by the global evaluation report (R0004).'}),
         self.base_name = modname
         self.base_file = normpath(filepath)
         # check this module
+        self._ignore_file = False
         astng = self._check_file(filepath, modname, checkers)
         if astng is None:
             return
@@ -516,7 +535,8 @@ This is used by the global evaluation report (R0004).'}),
             # if its actually a c extension
             self.current_file = astng.file
             # and check it
-            self.check_astng_module(astng, checkers)
+            if not self.check_astng_module(astng, checkers):
+                astng = None
         return astng
         
     def set_current_module(self, modname, filepath=None):
@@ -564,6 +584,8 @@ This is used by the global evaluation report (R0004).'}),
             # invoke IRawChecker interface on self to fetch module/block
             # level options
             self.process_module(stream)
+            if self._ignore_file:
+                return False
             # walk ast to collect line numbers
             orig_state = self._module_msgs_state.copy()
             self._module_msgs_state = {}
@@ -576,6 +598,7 @@ This is used by the global evaluation report (R0004).'}),
         # generate events to astng checkers
         self.astng_events(astng, [checker for checker in checkers
                                   if implements(checker, IASTNGChecker)])
+        return True
     
     def astng_events(self, astng, checkers, _reversed_checkers=None):
         """generate event to astng checkers according to the current astng
@@ -722,20 +745,32 @@ def preprocess_options(args, search_for):
     values of <search_for> are callback functions to call when the option is
     found
     """
-    for i, arg in enumerate(args):
-        for option in search_for:
-            if arg.startswith('--%s=' % option):
-                search_for[option](option, arg[len(option)+3:])
+    i = 0
+    while i < len(args):
+        arg = args[i]
+        if arg.startswith('--'):
+            try:
+                option, val = arg[2:].split('=', 1)
+            except ValueError:
+                option, val = arg[2:], None
+            try:
+                cb, takearg = search_for[option]
                 del args[i]
-            elif arg == '--%s' % option:
-                search_for[option](option, args[i + 1])
-                del args[i:i+2]
+                if takearg and val is None:
+                    val = args[i]
+                    del args[i]
+                cb(option, val)
+            except KeyError:
+                i += 1
+        else:
+            i += 1
     
 class Run:
     """helper class to use as main for pylint :
     
     run(*sys.argv[1:])
     """
+    LinterClass = PyLinter
     option_groups = (
         ('Commands', 'Options which are actually commands. Options in this \
 group are mutually exclusive.'),
@@ -744,13 +779,28 @@ group are mutually exclusive.'),
     def __init__(self, args, reporter=None, quiet=0):
         self._rcfile = None
         self._plugins = []
-        preprocess_options(args, {'rcfile': self.cb_set_rcfile,
-                                  'load-plugins': self.cb_add_plugins})
-        self.linter = linter = PyLinter((
+        preprocess_options(args, {
+            # option: (callback, takearg)
+            'rpython-mode': (self.cb_rpython_mode, False),
+            'rcfile':       (self.cb_set_rcfile, True),
+            'load-plugins': (self.cb_add_plugins, True),
+            })
+        self.linter = linter = self.LinterClass((
             ('rcfile',
              {'action' : 'callback', 'callback' : lambda *args: 1,
               'type': 'string', 'metavar': '<file>',
               'help' : 'Specify a configuration file.'}),
+            
+            ('init-hook',
+             {'action' : 'callback', 'type' : 'string', 'metavar': '<code>',
+              'callback' : self.cb_init_hook,
+              'help' : 'Python code to execute, usually for sys.path \
+manipulation such as pygtk.require().'}),
+            
+            ('rpython-mode',
+             {'action' : 'callback', 'callback' : lambda *args: 1,
+              'help' : 'enable the rpython checker which is disabled by default'}),
+             #'help' : 'Run into Restricted Python analysis mode.'}),
 
             ('help-msg',
              {'action' : 'callback', 'type' : 'string', 'metavar': '<msg-id>',
@@ -806,7 +856,7 @@ There are 5 kind of message types :
     * (C) convention, for programming standard violation                       
     * (R) refactor, for bad code smell                                         
     * (W) warning, for python specific problems                                
-    * (E) error, for much probably bugs in the code
+    * (E) error, for much probably bugs in the code                            
     * (F) fatal, if an error occured which prevented pylint from doing further \
 processing.     
         ''')
@@ -847,6 +897,12 @@ processing.
             linter.check(args)
         sys.path.pop(0)
 
+    def cb_rpython_mode(self, name, value):
+        from pylint.checkers.rpython import RPythonChecker
+        RPythonChecker.enabled = True
+        #from pylint.rlint import RPyLinter
+        #self.LinterClass = RPyLinter
+        
     def cb_set_rcfile(self, name, value):
         """callback for option preprocessing (ie before optik parsing)"""
         self._rcfile = value
@@ -870,7 +926,7 @@ processing.
     
     def cb_generate_config(self, *args, **kwargs):
         """optik callback for sample config file generation"""
-        self.linter.generate_config()
+        self.linter.generate_config(skipsections=('COMMANDS',))
         sys.exit(0)
          
     def cb_generate_manpage(self, *args, **kwargs):
@@ -884,6 +940,10 @@ processing.
         self.linter.help_message(get_csv(value))
         sys.exit(0)
         
+    def cb_init_hook(self, option, opt_name, value, parser):
+        """exec arbitrary code to set sys.path for instance"""
+        exec value
+        
     def cb_list_messages(self, option, opt_name, value, parser):
         """optik callback for printing available messages"""
         self.linter.list_messages()
