@@ -2,7 +2,7 @@ import sys
 import unittest
 from cStringIO import StringIO
 
-from logilab.pylint.checkers import similar
+from pylint.checkers import similar
 
 
 class SimilarTC(unittest.TestCase):
